Python scripts in this directory talk to ORCA native API. Using '-h' option with each script should provide usage information. 

You can create/delete/modify/extend slices, as well as retrieve and modify properties of existing reservations.
